@@ -9,6 +9,7 @@ from kamosdk.config import (
     set_default_profile,
     create_profile,
     delete_profile,
+    clear_config,
 )
 from kamosdk.exceptions import InvalidProfile
 from kamocli.utils import abort, dumps
@@ -156,3 +157,10 @@ def delete(ctx: Context, profile: str = Argument(..., help="Profile name to dele
     profile = profile.lower()
     delete_profile(profile)
     secho("Profile '%s' has been deleted" % profile, bold=True)
+
+
+@app.command("clear")
+def delete(ctx: Context):
+    """delete all profiles"""
+    clear_config()
+    secho("All profiles have been deleted and cache has been cleared. Please use 'kamo profile add' to get started", bold=True)
