@@ -14,11 +14,11 @@ from pathlib import Path
 from typing import Dict, Tuple, Sequence, Optional
 import shutil
 
-from kamosdk.utils import domain_from_api_key
 
 from .exceptions import InvalidProfile
 
 root_config_folder = Path(os.path.expanduser("~/.kamo"))
+CONFIG_FILENAME = "config.yaml"
 
 log = logging.getLogger(__name__)
 
@@ -106,7 +106,7 @@ class Config:
 
 
 def _load_config() -> Dict:
-    config_file = root_config_folder.joinpath("config.yaml")
+    config_file = root_config_folder.joinpath(CONFIG_FILENAME)
     try:
         content = yaml.safe_load(config_file.open())
         if not isinstance(content, dict):
@@ -119,12 +119,19 @@ def _load_config() -> Dict:
 
 def save_config() -> None:
     config = Config()
-    config_filename = root_config_folder.joinpath("config.yaml")
+    config_filename = root_config_folder.joinpath(CONFIG_FILENAME)
     os.makedirs(root_config_folder, exist_ok=True)
     with config_filename.open("w") as conf_file:
         yaml.safe_dump(config.dict(), conf_file)
 
 
+def clear_config() -> None:
+    root_config_folder.joinpath(CONFIG_FILENAME).unlink(missing_ok=True)
+    try:
+        root_config_folder.joinpath("cache").rmdir()
+    except:
+        pass
+
 def _init_config() -> None:
     config = Config()
     config.set({"default_profile": None, "profiles": []})
@@ -132,10 +139,12 @@ def _init_config() -> None:
     if "profiles" not in content:
         content["profiles"] = {}
     for name, profile in content["profiles"].copy().items():
-        profile = _prepare_profile(profile)
-        if not profile:
-            log.warning("Profile '%s' is invalid and will be ignored", name)
-            del content["profiles"][name]
+        required_keys = ["api_key", "domain"]
+        for k in required_keys:
+            if k not in profile:
+                log.warning("Profile '%s' is invalid and will be ignored", name)
+                del content["profiles"][name]
+                break
 
     config.set(content)
 
@@ -149,7 +158,7 @@ def _prepare_profile(profile):
         if profile.get("domain"):
             ret["domain"] = profile["domain"]
         else:
-            ret["domain"] = domain_from_api_key(ret["api_key"])
+            log.error("Profile does not contain ")
     except Exception as e:
         log.error(f"Error preparing profile {profile}: {e}")
         return None
