@@ -59,13 +59,6 @@ def check_resp_error(resp):
         raise error from None
 
 
-def domain_from_api_key(api_key):
-    payload = decode_token(api_key)
-    parts = urlsplit(payload["iss"])
-    root_url = netloc = parts.netloc.split(".", 1)[-1]
-    return root_url
-
-
 def get_access_token(api_key, client_id, oauth_url):
     """ """
     log.info("Fetching access token from Cognito")
